==> scribus_1.4.4+dfsg1.orig.tar.xz: scribus-1.4.4/scribus/canvasmode_create.h <==
/*
 For general Scribus (>=1.3.2) copyright and licensing information please refer
 to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/



#ifndef CANVAS_MODE_CREATE_H
#define CANVAS_MODE_CREATE_H

#include "canvasmode.h"
#include "fpointarray.h"

class PageItem;
class ScribusMainWindow;
class ScribusView;
class UndoTransaction;

/**
  Handles the creation of new pageitems
*/
class CreateMode : public CanvasMode
{
public:
	CreateMode(ScribusView* view);

	virtual void enterEvent(QEvent *);
	virtual void leaveEvent(QEvent *);
	
	virtual void activate(bool);
	virtual void deactivate(bool);
	virtual void mouseDoubleClickEvent(QMouseEvent *m);
	virtual void mouseReleaseEvent(QMouseEvent *m);
	virtual void mouseMoveEvent(QMouseEvent *m);
	virtual void mousePressEvent(QMouseEvent *m);
	virtual void drawControls(QPainter* p);
	
// protected:
// 	void setResizeCursor(int);
	
private:
	inline bool GetItem(PageItem** pi); 
	void selectPage(QMouseEvent *m);
	void SetupDrawNoResize(int nr);

	PageItem* doCreateNewObject(void);
	bool      doOneClick(FPoint& startPoint, FPoint& endPoint);

	// We do not use PageItem::ItemType and PageItem::FrameType here
	// for the pure sake of not including pageitem.h
	void getFrameItemTypes(int& itemType, int& frameType);

	bool   inItemCreation;
	bool   m_MouseButtonPressed;
	FPoint mouseGlobalCoord;
	FPoint canvasPressCoord;
	FPoint canvasCurrCoord;
	FPoint createObjectPos;
	int    createObjectMode;
	int    createObjectSubMode;
	Qt::KeyboardModifiers modifiers;
	UndoTransaction* m_createTransaction;
};


#endif

==> scribus_1.5.5+dfsg.orig.tar.xz: scribus-1.5.5/scribus/canvasmode_create.h <==
/*
 For general Scribus (>=1.3.2) copyright and licensing information please refer
 to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/



#ifndef CANVAS_MODE_CREATE_H
#define CANVAS_MODE_CREATE_H

#include "canvasmode.h"
#include "fpointarray.h"
#include "text/frect.h"
#include "undotransaction.h"

class PageItem;
class ScribusMainWindow;
class ScribusView;

/**
  Handles the creation of new pageitems
*/
class CreateMode : public CanvasMode
{
	Q_OBJECT

public:
	explicit CreateMode(ScribusView* view);
	~CreateMode() override  = default;

	void enterEvent(QEvent *) override ;
	void leaveEvent(QEvent *) override ;
	
	void activate(bool) override ;
	void deactivate(bool) override ;
	void mouseDoubleClickEvent(QMouseEvent *m) override ;
	void mouseReleaseEvent(QMouseEvent *m) override ;
	void mouseMoveEvent(QMouseEvent *m) override ;
	void mousePressEvent(QMouseEvent *m) override ;
	void drawControls(QPainter* p) override ;
	
// protected:
// 	void setResizeCursor(int);
	
private:
	inline bool GetItem(PageItem** pi); 
	void selectPage(QMouseEvent *m);
	void SetupDrawNoResize(int nr);

	PageItem* doCreateNewObject();
	bool      doOneClick(FPoint& startPoint, FPoint& endPoint);

	// We do not use PageItem::ItemType and PageItem::FrameType here
	// for the pure sake of not including pageitem.h
	void getFrameItemTypes(int& itemType, int& frameType);

	/**
	 * Convenience function which given two points calculates and returns the
	 * normalized rectangle between the two points, adjusted to grid and guides.
	 *
	 * @param firstPoint the first point
	 * @param secondPoint the second point
	 * @return a normalized rectangle adjusted to grid and guides
	 */
	FRect adjustedRect(FPoint &firstPoint, FPoint &secondPoint);

	bool   inItemCreation;
	bool   m_MouseButtonPressed;
	FPoint mouseGlobalCoord;
	FPoint canvasPressCoord;
	FPoint canvasCurrCoord;
	FPoint createObjectPos;
	int    createObjectMode;
	int    createObjectSubMode;
	Qt::KeyboardModifiers modifiers;
	UndoTransaction m_createTransaction;
};


#endif
